@@ -16,7 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-A Gherkin parser written using pyparsing
+A Gherkin parser written using pyparsing.
 """
 
 from __future__ import unicode_literals
@@ -82,7 +82,7 @@ unicodePrintables = ''.join(chr(c) for c in range(65536)
 
 class ParseLocation(object):
     """
-    The location of a parsed node within the stream
+    The location of a parsed node within the stream.
     """
 
     def __init__(self, parent, s, loc, filename=None):
@@ -101,7 +101,7 @@ class ParseLocation(object):
     @property
     def file(self):
         """
-        Return the relative path to the file
+        Return the relative path to the file.
         """
 
         if self._file:
@@ -130,7 +130,7 @@ class Node(object):
 
     def represented(self, indent=0, annotate=True):
         """
-        Return a representation of the node
+        Return a representation of the node.
         """
 
         s = u' ' * indent + self.text.strip()
@@ -144,7 +144,10 @@ class Node(object):
 
 class Step(Node):
     """
-    A statement
+    A single statement within a test.
+
+    A :class:`Scenario` or :class:`Background` is composed of multiple
+    :class:`Step`.
     """
 
     def __init__(self, s, loc, tokens):
@@ -156,9 +159,40 @@ class Step(Node):
         token = tokens[0]
 
         self.sentence = u' '.join(token.sentence)
+        """The sentence parsed for this step."""
         self.table = list(map(list, token.table)) \
             if token.table else None
+        """
+        A Gherkin table as a list of lists.
+
+        e.g.:
+
+        .. code-block:: gherkin
+
+            Then I have fruit:
+                | apples | oranges |
+                | 0      | 2       |
+
+        Becomes:
+
+        .. code-block:: python
+
+            [['apples', 'oranges', '0', '2']]
+        """
         self.multiline = token.multiline
+        """
+        A Gherkin multiline string with the appropriate indenting removed.
+
+        .. code-block:: gherkin
+
+            Then I have poem:
+                \"\"\"
+                Glittering-Minded deathless Aphrodite,
+                I beg you, Zeus’s daughter, weaver of snares,
+                Don’t shatter my heart with fierce
+                Pain, goddess,
+                \"\"\"
+        """
 
     def __str__(self):
         return '<Step: "%s">' % self.sentence
@@ -169,9 +203,9 @@ class Step(Node):
     @classmethod
     def parse_steps_from_string(cls, string, **kwargs):
         """
-        Parse a number of steps, returns a list of steps
+        Parse a number of steps, returns a list of :class:`Step`.
 
-        This is used by step.behave_as
+        This is used by :func:`step.behave_as`.
         """
 
         tokens = parse(string=string, token='STATEMENTS', **kwargs)
@@ -181,7 +215,7 @@ class Step(Node):
     @property
     def feature(self):
         """
-        The feature this step is a part of
+        The :class:`Feature` this step is a part of.
         """
 
         try:
@@ -192,7 +226,7 @@ class Step(Node):
     @memoizedproperty
     def keys(self):
         """
-        Return the first row of a table if this statement contains one
+        Return the first row of a table if this statement contains one.
         """
         if self.table:
             return tuple(self.table[0])
@@ -203,7 +237,24 @@ class Step(Node):
     def hashes(self):
         """
         Return the table attached to the step as a list of hashes, where the
-        first row is the column headings
+        first row is the column headings.
+
+        e.g.:
+
+        .. code-block:: gherkin
+
+            Then I have fruit:
+                | apples | oranges |
+                | 0      | 2       |
+
+        Becomes:
+
+        .. code-block:: python
+
+            [{
+                'apples': '0',
+                'oranges': '2',
+            }]
         """
 
         if not self.table:
@@ -231,21 +282,21 @@ class Step(Node):
 
     def represented(self, indent=4, annotate=True):
         """
-        Represent the line
+        Render the line.
         """
 
         return super().represented(indent=indent, annotate=annotate)
 
     def represent_hashes(self, indent=6, **kwargs):
         """
-        Render the table
+        Render the table.
         """
 
         return strings.represent_table(self.table, indent=indent, **kwargs)
 
     def resolve_substitutions(self, outline):
         """
-        Creates a copy of the step with any <variables> resolved
+        Creates a copy of the step with any <variables> resolved.
         """
 
         self = deepcopy(self)
@@ -270,7 +321,7 @@ class Block(Node):
     """
     A generic block, e.g. Feature:, Scenario:
 
-    Blocks contain a number of statements
+    Blocks contain a number of statements.
     """
 
     def __init__(self, *args):
@@ -281,7 +332,7 @@ class Block(Node):
     @classmethod
     def add_statements(cls, tokens):
         """
-        Consume the statements to add to this block
+        Consume the statements to add to this block.
         """
 
         token = tokens[0]
@@ -300,7 +351,7 @@ class Block(Node):
 
     def represented(self, indent=2, annotate=True):
         """
-        Include block indents
+        Include block indents.
         """
 
         return super().represented(indent=indent, annotate=annotate)
@@ -308,7 +359,7 @@ class Block(Node):
 
 class TaggedBlock(Block):
     """
-    Tagged blocks contain type-specific child content as well as tags
+    Tagged blocks contain type-specific child content as well as tags.
     """
     def __init__(self, s, loc, tokens):
         super().__init__(s, loc, tokens)
@@ -338,12 +389,21 @@ class TaggedBlock(Block):
 
     @property
     def tags(self):
-        """Tags for the scenario, feature, etc."""
+        """
+        Tags for a feature.
+
+        Tags are applied to a feature using the appropriate Gherkin syntax:
+
+        .. code-block:: gherkin
+
+            @tag1 @tag2
+            Feature: Eat leaves
+        """
         return self._tags
 
     def represented(self, indent=0, annotate=True):
         """
-        Reresent a tagged block
+        Render a tagged block.
         """
 
         s = u' ' * indent + u'{keyword}: {name}'.format(keyword=self.keyword,
@@ -356,19 +416,19 @@ class TaggedBlock(Block):
 
     def represent_tags(self, indent=0):
         """
-        Represent the tags of a tagged block
+        Render the tags of a tagged block.
         """
 
         return u' ' * indent + u'  '.join(u'@%s' % tag for tag in self.tags)
 
 
 class Background(Block):
-    """Scenario background."""
+    """The background of all :class:`Scenario` in a :class:`Feature`."""
     pass
 
 
 class Scenario(TaggedBlock):
-    """Scenario."""
+    """A scenario within a :class:`Feature`."""
 
     @classmethod
     def add_statements(cls, tokens):
@@ -399,7 +459,7 @@ class Scenario(TaggedBlock):
 
     def represent_outlines(self, indent=4):
         """
-        Render the outlines table
+        Render the outlines table.
         """
 
         return strings.represent_table(self.outlines_table, indent=indent)
@@ -407,7 +467,7 @@ class Scenario(TaggedBlock):
     @memoizedproperty
     def max_length(self):
         """
-        The max length of the feature, description and child blocks
+        The max horizontal length of the feature, description and child blocks.
         """
 
         return max(
@@ -421,7 +481,7 @@ class Scenario(TaggedBlock):
     @memoizedproperty
     def outlines_table(self):
         """
-        Return the outlines as a table
+        Return the outlines as a table.
         """
 
         # get the list of column headings
@@ -441,12 +501,13 @@ class Scenario(TaggedBlock):
 
     @property
     def tags(self):
+        """Tags for the :attr:`feature` and the scenario."""
         return self._tags + self.feature.tags
 
     @property
     def evaluated(self):
         """
-        Yield the outline and steps
+        Yield the outline and steps.
         """
 
         for outline in self.outlines:
@@ -475,7 +536,7 @@ class Scenario(TaggedBlock):
 
 class Description(Node):
     """
-    The description block of a feature
+    The description block of a feature.
     """
 
     def __init__(self, s, loc, tokens):
@@ -500,7 +561,7 @@ class Description(Node):
 
     def represent_line(self, n, indent=2, annotate=True):
         """
-        Represent the nth line in the description
+        Render the nth line in the description.
         """
 
         line = self.lines[n]
@@ -517,7 +578,7 @@ class Description(Node):
     @memoizedproperty
     def description_at(self):
         """
-        Return a tuple of lines in the string containing the description
+        Return a tuple of lines in the string containing the description.
         """
 
         offset = self.described_at.line
@@ -541,12 +602,17 @@ class Description(Node):
 
 
 class Feature(TaggedBlock):
-    """Gherkin feature."""
+    """
+    A complete Gherkin feature.
+
+    Features can either be constructed :func:`from_file` or
+    :func:`from_string`.
+    """
 
     @classmethod
     def from_string(cls, string, **kwargs):
         """
-        Returns a Feature from a string
+        Parse a string into a :class:`Feature`.
         """
 
         return parse(string=string, token='FEATURE', **kwargs)[0]
@@ -554,7 +620,7 @@ class Feature(TaggedBlock):
     @classmethod
     def from_file(cls, filename, **kwargs):
         """
-        Parse a file or filename
+        Parse a file or filename into a :class:`Feature`.
         """
 
         self = parse(filename=filename, token='FEATURE', **kwargs)[0]
@@ -564,7 +630,7 @@ class Feature(TaggedBlock):
     @classmethod
     def add_blocks(cls, tokens):
         """
-        Add the background and other blocks to the feature
+        Add the background and other blocks to the feature.
         """
 
         token = tokens[0]
@@ -592,15 +658,15 @@ class Feature(TaggedBlock):
     @property
     def description(self):
         """
-        In order to remain compatible with the existing API we disassemble
-        the Description node
+        The description of the feature (the text that comes directly under
+        the feature).
         """
         return str(self.description_node)
 
     @property
     def feature(self):
         """
-        Convenience property for generic functions
+        Convenience property for generic functions.
         """
 
         return self
@@ -608,7 +674,9 @@ class Feature(TaggedBlock):
     @memoizedproperty
     def max_length(self):
         """
-        The max length of the feature, description and child blocks
+        The max horizontal length of the feature, description and child blocks.
+
+        This is used for aligning rendered output.
         """
 
         return max(
@@ -634,7 +702,7 @@ class Feature(TaggedBlock):
 
 def guess_language(string=None, filename=None):
     """
-    Attempt to guess the language
+    Attempt to guess the language.
 
     Do this by parsing the comments at the top of the file for the
 
@@ -718,7 +786,7 @@ def parse(string=None,
           language=None,
           constructors=None):
     """
-    Parse a token stream from or raise a SyntaxError
+    Parse a token stream from or raise a SyntaxError.
 
     This function includes the parser grammar.
     """
@@ -793,7 +861,7 @@ def parse(string=None,
     #
     def clean_multiline_string(s, loc, tokens):
         """
-        Clean a multiline string
+        Clean a multiline string.
 
         The indent level of a multiline string is the indent level of the
         triple-". We have to derive this by walking backwards from the
